==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/lv-LV/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Dienas',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Pabeidzis aktīvu pārskats.',
    'Expiring_Licenses_Report' => 'Pabeidzamo licenču pārskats.',
    'Item_Request_Canceled' => 'Vienuma pieprasījums atcelts',
    'Item_Requested' => 'Pieprasīts vienums',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Zema inventarizācijas atskaite',
    'a_user_canceled' => 'Lietotājs vietnē ir atcēlis objekta pieprasījumu',
    'a_user_requested' => 'Lietotājs ir pieprasījis vienumu vietnē',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Piederuma nosaukums',
    'additional_notes' => 'Papildu piezīmes',
    'admin_has_created' => 'Administrators ir izveidojis jums kontu: tīmekļa vietnē.',
    'asset' => 'Aktīvs',
    'asset_name' => 'Aktīva nosaukums',
    'asset_requested' => 'Aktīvs pieprasīts',
    'asset_tag' => 'Asset Tag',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Piešķirts',
    'best_regards' => 'Ar laba vēlējumiem,',
    'canceled' => 'Atcelts',
    'checkin_date' => 'Reģistrēšanās datums',
    'checkout_date' => 'Izrakstīšanās datums',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Lūdzu, noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat saņēmis piederumu.',
    'click_on_the_link_asset' => 'Lūdzu, noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat saņēmis šo īpašumu.',
    'click_to_confirm' => 'Lūdzu, noklikšķiniet uz šīs saites, lai apstiprinātu savu: tīmekļa kontu:',
    'current_QTY' => 'Pašreizējais QTY',
    'days' => 'Dienas',
    'expecting_checkin_date' => 'Paredzamais reģistrēšanās datums',
    'expires' => 'Beidzas',
    'hello' => 'Sveiki',
    'hi' => 'Sveiki',
    'i_have_read' => 'Esmu izlasījis un piekrītu lietošanas noteikumiem un saņēmu šo preci.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Vienums',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Pēc :threshold dienām beigsies termiņš :count licencei.| Pēc :threshold dienām beigsies termiņš :threshold :count licencēm.',
    'link_to_update_password' => 'Lūdzu, noklikšķiniet uz šīs saites, lai atjauninātu savu: web paroli:',
    'login' => 'Pieslēgties',
    'login_first_admin' => 'Piesakieties savā jaunajā Snipe-IT instalācijā, izmantojot tālāk minētos akreditācijas datus.',
    'low_inventory_alert' => ':count vienības skaits ir zemāks par krājuma minimumu vai drīz būs zems.|:count vienību skaits ir zemāks par krājuma minimumu vai drīz būs zems.',
    'min_QTY' => 'Min QTY',
    'name' => 'Nosaukums',
    'new_item_checked' => 'Jauns objekts ir atzīmēts zem sava vārda, sīkāk ir sniegta zemāk.',
    'notes' => 'Piezīmes',
    'password' => 'Parole',
    'password_reset' => 'Paroles atiestatīšana',
    'read_the_terms' => 'Lūdzu, izlasiet lietošanas noteikumus zemāk.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Pieprasīts',
    'reset_link' => 'Jūsu paroles atiestatīšanas saite',
    'reset_password' => 'Noklikšķiniet šeit, lai atiestatītu savu paroli:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Sērijas numurs',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Piegādātājs',
    'tag' => 'Tag',
    'test_email' => 'Pārbaudiet e-pastu no Snipe-IT',
    'test_mail_text' => 'Šis ir tests no Snipe-IT Asset Management System. Ja jums ir šis, pasts darbojas :)',
    'the_following_item' => 'Šis ieraksts ir atzīmēts:',
    'to_reset' => 'Lai atiestatītu: tīmekļa paroli, aizpildiet šo veidlapu:',
    'type' => 'Tips',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Lietotājs',
    'username' => 'Lietotājvārds',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Sveicināti: vārds',
    'welcome_to' => 'Laipni lūdzam: tīmeklī!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Jūsu Snipe-IT akreditācijas dati',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/lv-LV/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out|:count Accessories checked out',
    'Asset_Checkin_Notification' => 'Asset checked in: :tag',
    'Asset_Checkout_Notification' => 'Asset checked out: :tag',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_component_checkin' => 'Component checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_component_delivery' => 'Component delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Component_checkout_notification' => 'Component checked out',
    'Component_checkin_notification' => 'Component checked in',
    'Days' => 'Dienas',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Pabeidzis aktīvu pārskats',
    'Expiring_Licenses_Report' => 'Pabeidzamo licenču pārskats',
    'Item_Request_Canceled' => 'Vienuma pieprasījums atcelts',
    'Item_Requested' => 'Pieprasīts vienums',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Zema inventarizācijas atskaite',
    'a_user_canceled' => 'Lietotājs vietnē ir atcēlis objekta pieprasījumu',
    'a_user_requested' => 'Lietotājs ir pieprasījis vienumu vietnē',
    'acceptance_asset_accepted_to_user' => 'You have accepted an item assigned to you by :site_name|You have accepted :qty items assigned to you by :site_name',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'send_pdf_copy' => 'Send a copy of this acceptance to my email address',
    'accessory_name' => 'Piederuma nosaukums',
    'additional_notes' => 'Papildu piezīmes',
    'admin_has_created' => 'An administrator has created an account for you on the :web website. Please find your username below, and click on the link to set a password.',
    'asset' => 'Aktīvs',
    'asset_name' => 'Aktīva nosaukums',
    'asset_requested' => 'Aktīvs pieprasīts',
    'asset_tag' => 'Asset Tag',
    'assets_warrantee_alert' => 'There is :count asset with an expiring warranty or that are reaching their end of life in the next :threshold days.|There are :count assets with expiring warranties or that are reaching their end of life in the next :threshold days.',
    'assigned_to' => 'Piešķirts',
    'eol' => 'EOL',
    'best_regards' => 'Ar laba vēlējumiem,',
    'canceled' => 'Atcelts',
    'checkin_date' => 'Reģistrēšanās datums',
    'checkout_date' => 'Izrakstīšanās datums',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Lūdzu, noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat saņēmis piederumu.',
    'click_on_the_link_asset' => 'Lūdzu, noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat saņēmis šo īpašumu.',
    'click_to_confirm' => 'Lūdzu, noklikšķiniet uz šīs saites, lai apstiprinātu savu: tīmekļa kontu:',
    'current_QTY' => 'Pašreizējais QTY',
    'days' => 'Dienas',
    'expecting_checkin_date' => 'Paredzamais reģistrēšanās datums',
    'expires' => 'Beidzas',
    'terminates' => 'Terminates',
    'following_accepted' => 'The following was accepted',
    'following_declined' => 'The following was declined',
    'hello' => 'Sveiki',
    'hi' => 'Sveiki',
    'i_have_read' => 'Esmu izlasījis un piekrītu lietošanas noteikumiem un saņēmu šo preci.',
    'initiated_accepted' => 'A checkout you initiated was accepted',
    'initiated_declined' => 'A checkout you initiated was declined',
    'inventory_report' => 'Inventory Report',
    'item' => 'Vienums',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring or terminating in the next :threshold days.|There are :count licenses expiring or terminating in the next :threshold days.',
    'link_to_update_password' => 'Lūdzu, noklikšķiniet uz šīs saites, lai atjauninātu savu: web paroli:',
    'login' => 'Pieslēgties',
    'login_first_admin' => 'Piesakieties savā jaunajā Snipe-IT instalācijā, izmantojot tālāk minētos akreditācijas datus.',
    'low_inventory_alert' => ':count vienības skaits ir zemāks par krājuma minimumu vai drīz būs zems.|:count vienību skaits ir zemāks par krājuma minimumu vai drīz būs zems.',
    'min_QTY' => 'Min QTY',
    'name' => 'Nosaukums',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.|:count new items have been checked out under your name, details are below.',
    'new_item_checked_with_acceptance' => 'A new item has been checked out under your name that requires acceptance, details are below.|:count new items have been checked out under your name that requires acceptance, details are below.',
    'new_item_checked_location' => 'A new item has been checked out to :location, details are below.|:count new items have been checked out to :location, details are below.',
    'recent_item_checked' => 'An item was recently checked out under your name that requires acceptance, details are below.',
    'notes' => 'Piezīmes',
    'password' => 'Parole',
    'password_reset' => 'Paroles atiestatīšana',
    'read_the_terms' => 'Lūdzu, izlasiet lietošanas noteikumus zemāk.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Pieprasīts',
    'reset_link' => 'Jūsu paroles atiestatīšanas saite',
    'reset_password' => 'Noklikšķiniet šeit, lai atiestatītu savu paroli:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Sērijas numurs',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Piegādātājs',
    'tag' => 'Tag',
    'test_email' => 'Pārbaudiet e-pastu no Snipe-IT',
    'test_mail_text' => 'Šis ir tests no Snipe-IT Asset Management System. Ja jums ir šis, pasts darbojas :)',
    'the_following_item' => 'Šis ieraksts ir atzīmēts:',
    'to_reset' => 'Lai atiestatītu: tīmekļa paroli, aizpildiet šo veidlapu:',
    'type' => 'Tips',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Lietotājs',
    'username' => 'Lietotājvārds',
    'unaccepted_asset_reminder' => 'Reminder: You have Unaccepted Assets.',
    'welcome' => 'Sveicināti: vārds',
    'welcome_to' => 'Laipni lūdzam: tīmeklī!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Jūsu Snipe-IT akreditācijas dati',
    'mail_sent' => 'Mail sent successfully!',
];
